Class: Candid::FeeSchedules::V3::Types::RateEntry

Inherits:
Internal::Types::Model show all
Defined in:
lib/candid/fee_schedules/v_3/types/rate_entry.rb

Overview

A rate value in cents for a specific time range. Rate entries can be deactivated, which is set by using the deelte_rate endpoint. Deactivated rate entries are not considered when matching against service lines.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Candid::Internal::Types::Model